Learn R Programming

vein (version 0.5.2)

ef_cetesb: Emissions factors for Environment Company of Sao Paulo, Brazil (CETESB) 2016

Description

ef_cetesb returns a vector or data.frame of Brazilian emission factors.

Usage

ef_cetesb(p, veh, full = FALSE)

Arguments

p

Character; Pollutants: "COd", "HCd", "NMHCd", "CH4", "NOxd", "CO2" "PM", "N2O", "KML", "FC", "NO2d", "NOd", "gD/KWH", "gCO2/KWH", "RCHOd", "SO2" "CO", "HC", "NMHC", "NOx", "NO2" ,"NO", "RCHO". The letter 'd' means deteriorated factor.

veh

Character; Vehicle categories: "PC_G", "PC_FG", "PC_FE", "PC_E" "LCV_G", "LCV_FG", "LCV_FE", "LCV_E", "LCV_D", "SLT", "LT", "MT", "SHT" "HT", "UB", "SUB", "COACH", "ARTIC", "M_G_150", "M_G_150_500", "M_G_500" "M_FG_150", "M_FG_150_500", "M_FG_500". "M_FE_150", "M_FE_150_500", "M_FE_500", "CICLOMOTOR", "GNV

full

Logical; To return a data.frame instead or a vector adding Age, Year, Brazilian emissions standards and its euro equivalents.

Value

A vector of Emission Factor or a data.frame

References

Emissoes Veiculares no Estado de Sao Paulo 2016. Technical Report. url: https://cetesb.sp.gov.br/veicular/relatorios-e-publicacoes/.

Examples

Run this code
# NOT RUN {
{
a <- ef_cetesb("CO", "PC_G")
}
# }

Run the code above in your browser using DataLab